@@ -1,7 +1,7 @@
 """
 Type annotations for swf service type definitions.
 
-[Open documentation](./type_defs.md)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/type_defs.html)
 
 Usage::
 
@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Union
 
 from .literals import (
     ActivityTaskTimeoutTypeType,
@@ -78,12 +78,23 @@ __all__ = (
     "CompleteWorkflowExecutionFailedEventAttributesTypeDef",
     "ContinueAsNewWorkflowExecutionDecisionAttributesTypeDef",
     "ContinueAsNewWorkflowExecutionFailedEventAttributesTypeDef",
+    "CountClosedWorkflowExecutionsInputRequestTypeDef",
+    "CountOpenWorkflowExecutionsInputRequestTypeDef",
+    "CountPendingActivityTasksInputRequestTypeDef",
+    "CountPendingDecisionTasksInputRequestTypeDef",
     "DecisionTaskCompletedEventAttributesTypeDef",
     "DecisionTaskScheduledEventAttributesTypeDef",
     "DecisionTaskStartedEventAttributesTypeDef",
     "DecisionTaskTimedOutEventAttributesTypeDef",
     "DecisionTaskTypeDef",
     "DecisionTypeDef",
+    "DeprecateActivityTypeInputRequestTypeDef",
+    "DeprecateDomainInputRequestTypeDef",
+    "DeprecateWorkflowTypeInputRequestTypeDef",
+    "DescribeActivityTypeInputRequestTypeDef",
+    "DescribeDomainInputRequestTypeDef",
+    "DescribeWorkflowExecutionInputRequestTypeDef",
+    "DescribeWorkflowTypeInputRequestTypeDef",
     "DomainConfigurationTypeDef",
     "DomainDetailTypeDef",
     "DomainInfoTypeDef",
@@ -93,6 +104,7 @@ __all__ = (
     "ExternalWorkflowExecutionSignaledEventAttributesTypeDef",
     "FailWorkflowExecutionDecisionAttributesTypeDef",
     "FailWorkflowExecutionFailedEventAttributesTypeDef",
+    "GetWorkflowExecutionHistoryInputRequestTypeDef",
     "HistoryEventTypeDef",
     "HistoryTypeDef",
     "LambdaFunctionCompletedEventAttributesTypeDef",
@@ -100,18 +112,35 @@ __all__ = (
     "LambdaFunctionScheduledEventAttributesTypeDef",
     "LambdaFunctionStartedEventAttributesTypeDef",
     "LambdaFunctionTimedOutEventAttributesTypeDef",
+    "ListActivityTypesInputRequestTypeDef",
+    "ListClosedWorkflowExecutionsInputRequestTypeDef",
+    "ListDomainsInputRequestTypeDef",
+    "ListOpenWorkflowExecutionsInputRequestTypeDef",
+    "ListTagsForResourceInputRequestTypeDef",
     "ListTagsForResourceOutputTypeDef",
+    "ListWorkflowTypesInputRequestTypeDef",
     "MarkerRecordedEventAttributesTypeDef",
     "PaginatorConfigTypeDef",
     "PendingTaskCountTypeDef",
+    "PollForActivityTaskInputRequestTypeDef",
+    "PollForDecisionTaskInputRequestTypeDef",
+    "RecordActivityTaskHeartbeatInputRequestTypeDef",
     "RecordMarkerDecisionAttributesTypeDef",
     "RecordMarkerFailedEventAttributesTypeDef",
+    "RegisterActivityTypeInputRequestTypeDef",
+    "RegisterDomainInputRequestTypeDef",
+    "RegisterWorkflowTypeInputRequestTypeDef",
     "RequestCancelActivityTaskDecisionAttributesTypeDef",
     "RequestCancelActivityTaskFailedEventAttributesTypeDef",
     "RequestCancelExternalWorkflowExecutionDecisionAttributesTypeDef",
     "RequestCancelExternalWorkflowExecutionFailedEventAttributesTypeDef",
     "RequestCancelExternalWorkflowExecutionInitiatedEventAttributesTypeDef",
+    "RequestCancelWorkflowExecutionInputRequestTypeDef",
     "ResourceTagTypeDef",
+    "RespondActivityTaskCanceledInputRequestTypeDef",
+    "RespondActivityTaskCompletedInputRequestTypeDef",
+    "RespondActivityTaskFailedInputRequestTypeDef",
+    "RespondDecisionTaskCompletedInputRequestTypeDef",
     "ResponseMetadataTypeDef",
     "RunTypeDef",
     "ScheduleActivityTaskDecisionAttributesTypeDef",
@@ -121,17 +150,25 @@ __all__ = (
     "SignalExternalWorkflowExecutionDecisionAttributesTypeDef",
     "SignalExternalWorkflowExecutionFailedEventAttributesTypeDef",
     "SignalExternalWorkflowExecutionInitiatedEventAttributesTypeDef",
+    "SignalWorkflowExecutionInputRequestTypeDef",
     "StartChildWorkflowExecutionDecisionAttributesTypeDef",
     "StartChildWorkflowExecutionFailedEventAttributesTypeDef",
     "StartChildWorkflowExecutionInitiatedEventAttributesTypeDef",
     "StartLambdaFunctionFailedEventAttributesTypeDef",
     "StartTimerDecisionAttributesTypeDef",
     "StartTimerFailedEventAttributesTypeDef",
+    "StartWorkflowExecutionInputRequestTypeDef",
     "TagFilterTypeDef",
+    "TagResourceInputRequestTypeDef",
     "TaskListTypeDef",
+    "TerminateWorkflowExecutionInputRequestTypeDef",
     "TimerCanceledEventAttributesTypeDef",
     "TimerFiredEventAttributesTypeDef",
     "TimerStartedEventAttributesTypeDef",
+    "UndeprecateActivityTypeInputRequestTypeDef",
+    "UndeprecateDomainInputRequestTypeDef",
+    "UndeprecateWorkflowTypeInputRequestTypeDef",
+    "UntagResourceInputRequestTypeDef",
     "WorkflowExecutionCancelRequestedEventAttributesTypeDef",
     "WorkflowExecutionCanceledEventAttributesTypeDef",
     "WorkflowExecutionCompletedEventAttributesTypeDef",
@@ -293,6 +330,7 @@ ActivityTaskStatusTypeDef = TypedDict(
     "ActivityTaskStatusTypeDef",
     {
         "cancelRequested": bool,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
@@ -320,29 +358,19 @@ class ActivityTaskTimedOutEventAttributesTypeDef(
     pass
 
 
-_RequiredActivityTaskTypeDef = TypedDict(
-    "_RequiredActivityTaskTypeDef",
+ActivityTaskTypeDef = TypedDict(
+    "ActivityTaskTypeDef",
     {
         "taskToken": str,
         "activityId": str,
         "startedEventId": int,
         "workflowExecution": "WorkflowExecutionTypeDef",
         "activityType": "ActivityTypeTypeDef",
-    },
-)
-_OptionalActivityTaskTypeDef = TypedDict(
-    "_OptionalActivityTaskTypeDef",
-    {
         "input": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-
-class ActivityTaskTypeDef(_RequiredActivityTaskTypeDef, _OptionalActivityTaskTypeDef):
-    pass
-
-
 ActivityTypeConfigurationTypeDef = TypedDict(
     "ActivityTypeConfigurationTypeDef",
     {
@@ -361,6 +389,7 @@ ActivityTypeDetailTypeDef = TypedDict(
     {
         "typeInfo": "ActivityTypeInfoTypeDef",
         "configuration": "ActivityTypeConfigurationTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
@@ -386,27 +415,15 @@ class ActivityTypeInfoTypeDef(_RequiredActivityTypeInfoTypeDef, _OptionalActivit
     pass
 
 
-_RequiredActivityTypeInfosTypeDef = TypedDict(
-    "_RequiredActivityTypeInfosTypeDef",
+ActivityTypeInfosTypeDef = TypedDict(
+    "ActivityTypeInfosTypeDef",
     {
         "typeInfos": List["ActivityTypeInfoTypeDef"],
-    },
-)
-_OptionalActivityTypeInfosTypeDef = TypedDict(
-    "_OptionalActivityTypeInfosTypeDef",
-    {
         "nextPageToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-
-class ActivityTypeInfosTypeDef(
-    _RequiredActivityTypeInfosTypeDef, _OptionalActivityTypeInfosTypeDef
-):
-    pass
-
-
 ActivityTypeTypeDef = TypedDict(
     "ActivityTypeTypeDef",
     {
@@ -600,6 +617,74 @@ ContinueAsNewWorkflowExecutionFailedEventAttributesTypeDef = TypedDict(
     },
 )
 
+_RequiredCountClosedWorkflowExecutionsInputRequestTypeDef = TypedDict(
+    "_RequiredCountClosedWorkflowExecutionsInputRequestTypeDef",
+    {
+        "domain": str,
+    },
+)
+_OptionalCountClosedWorkflowExecutionsInputRequestTypeDef = TypedDict(
+    "_OptionalCountClosedWorkflowExecutionsInputRequestTypeDef",
+    {
+        "startTimeFilter": "ExecutionTimeFilterTypeDef",
+        "closeTimeFilter": "ExecutionTimeFilterTypeDef",
+        "executionFilter": "WorkflowExecutionFilterTypeDef",
+        "typeFilter": "WorkflowTypeFilterTypeDef",
+        "tagFilter": "TagFilterTypeDef",
+        "closeStatusFilter": "CloseStatusFilterTypeDef",
+    },
+    total=False,
+)
+
+
+class CountClosedWorkflowExecutionsInputRequestTypeDef(
+    _RequiredCountClosedWorkflowExecutionsInputRequestTypeDef,
+    _OptionalCountClosedWorkflowExecutionsInputRequestTypeDef,
+):
+    pass
+
+
+_RequiredCountOpenWorkflowExecutionsInputRequestTypeDef = TypedDict(
+    "_RequiredCountOpenWorkflowExecutionsInputRequestTypeDef",
+    {
+        "domain": str,
+        "startTimeFilter": "ExecutionTimeFilterTypeDef",
+    },
+)
+_OptionalCountOpenWorkflowExecutionsInputRequestTypeDef = TypedDict(
+    "_OptionalCountOpenWorkflowExecutionsInputRequestTypeDef",
+    {
+        "typeFilter": "WorkflowTypeFilterTypeDef",
+        "tagFilter": "TagFilterTypeDef",
+        "executionFilter": "WorkflowExecutionFilterTypeDef",
+    },
+    total=False,
+)
+
+
+class CountOpenWorkflowExecutionsInputRequestTypeDef(
+    _RequiredCountOpenWorkflowExecutionsInputRequestTypeDef,
+    _OptionalCountOpenWorkflowExecutionsInputRequestTypeDef,
+):
+    pass
+
+
+CountPendingActivityTasksInputRequestTypeDef = TypedDict(
+    "CountPendingActivityTasksInputRequestTypeDef",
+    {
+        "domain": str,
+        "taskList": "TaskListTypeDef",
+    },
+)
+
+CountPendingDecisionTasksInputRequestTypeDef = TypedDict(
+    "CountPendingDecisionTasksInputRequestTypeDef",
+    {
+        "domain": str,
+        "taskList": "TaskListTypeDef",
+    },
+)
+
 _RequiredDecisionTaskCompletedEventAttributesTypeDef = TypedDict(
     "_RequiredDecisionTaskCompletedEventAttributesTypeDef",
     {
@@ -677,30 +762,20 @@ DecisionTaskTimedOutEventAttributesTypeDef = TypedDict(
     },
 )
 
-_RequiredDecisionTaskTypeDef = TypedDict(
-    "_RequiredDecisionTaskTypeDef",
+DecisionTaskTypeDef = TypedDict(
+    "DecisionTaskTypeDef",
     {
         "taskToken": str,
         "startedEventId": int,
         "workflowExecution": "WorkflowExecutionTypeDef",
         "workflowType": "WorkflowTypeTypeDef",
         "events": List["HistoryEventTypeDef"],
-    },
-)
-_OptionalDecisionTaskTypeDef = TypedDict(
-    "_OptionalDecisionTaskTypeDef",
-    {
         "nextPageToken": str,
         "previousStartedEventId": int,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-
-class DecisionTaskTypeDef(_RequiredDecisionTaskTypeDef, _OptionalDecisionTaskTypeDef):
-    pass
-
-
 _RequiredDecisionTypeDef = TypedDict(
     "_RequiredDecisionTypeDef",
     {
@@ -732,6 +807,60 @@ class DecisionTypeDef(_RequiredDecisionTypeDef, _OptionalDecisionTypeDef):
     pass
 
 
+DeprecateActivityTypeInputRequestTypeDef = TypedDict(
+    "DeprecateActivityTypeInputRequestTypeDef",
+    {
+        "domain": str,
+        "activityType": "ActivityTypeTypeDef",
+    },
+)
+
+DeprecateDomainInputRequestTypeDef = TypedDict(
+    "DeprecateDomainInputRequestTypeDef",
+    {
+        "name": str,
+    },
+)
+
+DeprecateWorkflowTypeInputRequestTypeDef = TypedDict(
+    "DeprecateWorkflowTypeInputRequestTypeDef",
+    {
+        "domain": str,
+        "workflowType": "WorkflowTypeTypeDef",
+    },
+)
+
+DescribeActivityTypeInputRequestTypeDef = TypedDict(
+    "DescribeActivityTypeInputRequestTypeDef",
+    {
+        "domain": str,
+        "activityType": "ActivityTypeTypeDef",
+    },
+)
+
+DescribeDomainInputRequestTypeDef = TypedDict(
+    "DescribeDomainInputRequestTypeDef",
+    {
+        "name": str,
+    },
+)
+
+DescribeWorkflowExecutionInputRequestTypeDef = TypedDict(
+    "DescribeWorkflowExecutionInputRequestTypeDef",
+    {
+        "domain": str,
+        "execution": "WorkflowExecutionTypeDef",
+    },
+)
+
+DescribeWorkflowTypeInputRequestTypeDef = TypedDict(
+    "DescribeWorkflowTypeInputRequestTypeDef",
+    {
+        "domain": str,
+        "workflowType": "WorkflowTypeTypeDef",
+    },
+)
+
 DomainConfigurationTypeDef = TypedDict(
     "DomainConfigurationTypeDef",
     {
@@ -744,6 +873,7 @@ DomainDetailTypeDef = TypedDict(
     {
         "domainInfo": "DomainInfoTypeDef",
         "configuration": "DomainConfigurationTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
@@ -768,35 +898,25 @@ class DomainInfoTypeDef(_RequiredDomainInfoTypeDef, _OptionalDomainInfoTypeDef):
     pass
 
 
-_RequiredDomainInfosTypeDef = TypedDict(
-    "_RequiredDomainInfosTypeDef",
+DomainInfosTypeDef = TypedDict(
+    "DomainInfosTypeDef",
     {
         "domainInfos": List["DomainInfoTypeDef"],
-    },
-)
-_OptionalDomainInfosTypeDef = TypedDict(
-    "_OptionalDomainInfosTypeDef",
-    {
         "nextPageToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-
-class DomainInfosTypeDef(_RequiredDomainInfosTypeDef, _OptionalDomainInfosTypeDef):
-    pass
-
-
 _RequiredExecutionTimeFilterTypeDef = TypedDict(
     "_RequiredExecutionTimeFilterTypeDef",
     {
-        "oldestDate": datetime,
+        "oldestDate": Union[datetime, str],
     },
 )
 _OptionalExecutionTimeFilterTypeDef = TypedDict(
     "_OptionalExecutionTimeFilterTypeDef",
     {
-        "latestDate": datetime,
+        "latestDate": Union[datetime, str],
     },
     total=False,
 )
@@ -841,6 +961,31 @@ FailWorkflowExecutionFailedEventAttributesTypeDef = TypedDict(
     },
 )
 
+_RequiredGetWorkflowExecutionHistoryInputRequestTypeDef = TypedDict(
+    "_RequiredGetWorkflowExecutionHistoryInputRequestTypeDef",
+    {
+        "domain": str,
+        "execution": "WorkflowExecutionTypeDef",
+    },
+)
+_OptionalGetWorkflowExecutionHistoryInputRequestTypeDef = TypedDict(
+    "_OptionalGetWorkflowExecutionHistoryInputRequestTypeDef",
+    {
+        "nextPageToken": str,
+        "maximumPageSize": int,
+        "reverseOrder": bool,
+    },
+    total=False,
+)
+
+
+class GetWorkflowExecutionHistoryInputRequestTypeDef(
+    _RequiredGetWorkflowExecutionHistoryInputRequestTypeDef,
+    _OptionalGetWorkflowExecutionHistoryInputRequestTypeDef,
+):
+    pass
+
+
 _RequiredHistoryEventTypeDef = TypedDict(
     "_RequiredHistoryEventTypeDef",
     {
@@ -915,25 +1060,15 @@ class HistoryEventTypeDef(_RequiredHistoryEventTypeDef, _OptionalHistoryEventTyp
     pass
 
 
-_RequiredHistoryTypeDef = TypedDict(
-    "_RequiredHistoryTypeDef",
+HistoryTypeDef = TypedDict(
+    "HistoryTypeDef",
     {
         "events": List["HistoryEventTypeDef"],
-    },
-)
-_OptionalHistoryTypeDef = TypedDict(
-    "_OptionalHistoryTypeDef",
-    {
         "nextPageToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-
-class HistoryTypeDef(_RequiredHistoryTypeDef, _OptionalHistoryTypeDef):
-    pass
-
-
 _RequiredLambdaFunctionCompletedEventAttributesTypeDef = TypedDict(
     "_RequiredLambdaFunctionCompletedEventAttributesTypeDef",
     {
@@ -1037,6 +1172,119 @@ class LambdaFunctionTimedOutEventAttributesTypeDef(
     pass
 
 
+_RequiredListActivityTypesInputRequestTypeDef = TypedDict(
+    "_RequiredListActivityTypesInputRequestTypeDef",
+    {
+        "domain": str,
+        "registrationStatus": RegistrationStatusType,
+    },
+)
+_OptionalListActivityTypesInputRequestTypeDef = TypedDict(
+    "_OptionalListActivityTypesInputRequestTypeDef",
+    {
+        "name": str,
+        "nextPageToken": str,
+        "maximumPageSize": int,
+        "reverseOrder": bool,
+    },
+    total=False,
+)
+
+
+class ListActivityTypesInputRequestTypeDef(
+    _RequiredListActivityTypesInputRequestTypeDef, _OptionalListActivityTypesInputRequestTypeDef
+):
+    pass
+
+
+_RequiredListClosedWorkflowExecutionsInputRequestTypeDef = TypedDict(
+    "_RequiredListClosedWorkflowExecutionsInputRequestTypeDef",
+    {
+        "domain": str,
+    },
+)
+_OptionalListClosedWorkflowExecutionsInputRequestTypeDef = TypedDict(
+    "_OptionalListClosedWorkflowExecutionsInputRequestTypeDef",
+    {
+        "startTimeFilter": "ExecutionTimeFilterTypeDef",
+        "closeTimeFilter": "ExecutionTimeFilterTypeDef",
+        "executionFilter": "WorkflowExecutionFilterTypeDef",
+        "closeStatusFilter": "CloseStatusFilterTypeDef",
+        "typeFilter": "WorkflowTypeFilterTypeDef",
+        "tagFilter": "TagFilterTypeDef",
+        "nextPageToken": str,
+        "maximumPageSize": int,
+        "reverseOrder": bool,
+    },
+    total=False,
+)
+
+
+class ListClosedWorkflowExecutionsInputRequestTypeDef(
+    _RequiredListClosedWorkflowExecutionsInputRequestTypeDef,
+    _OptionalListClosedWorkflowExecutionsInputRequestTypeDef,
+):
+    pass
+
+
+_RequiredListDomainsInputRequestTypeDef = TypedDict(
+    "_RequiredListDomainsInputRequestTypeDef",
+    {
+        "registrationStatus": RegistrationStatusType,
+    },
+)
+_OptionalListDomainsInputRequestTypeDef = TypedDict(
+    "_OptionalListDomainsInputRequestTypeDef",
+    {
+        "nextPageToken": str,
+        "maximumPageSize": int,
+        "reverseOrder": bool,
+    },
+    total=False,
+)
+
+
+class ListDomainsInputRequestTypeDef(
+    _RequiredListDomainsInputRequestTypeDef, _OptionalListDomainsInputRequestTypeDef
+):
+    pass
+
+
+_RequiredListOpenWorkflowExecutionsInputRequestTypeDef = TypedDict(
+    "_RequiredListOpenWorkflowExecutionsInputRequestTypeDef",
+    {
+        "domain": str,
+        "startTimeFilter": "ExecutionTimeFilterTypeDef",
+    },
+)
+_OptionalListOpenWorkflowExecutionsInputRequestTypeDef = TypedDict(
+    "_OptionalListOpenWorkflowExecutionsInputRequestTypeDef",
+    {
+        "typeFilter": "WorkflowTypeFilterTypeDef",
+        "tagFilter": "TagFilterTypeDef",
+        "nextPageToken": str,
+        "maximumPageSize": int,
+        "reverseOrder": bool,
+        "executionFilter": "WorkflowExecutionFilterTypeDef",
+    },
+    total=False,
+)
+
+
+class ListOpenWorkflowExecutionsInputRequestTypeDef(
+    _RequiredListOpenWorkflowExecutionsInputRequestTypeDef,
+    _OptionalListOpenWorkflowExecutionsInputRequestTypeDef,
+):
+    pass
+
+
+ListTagsForResourceInputRequestTypeDef = TypedDict(
+    "ListTagsForResourceInputRequestTypeDef",
+    {
+        "resourceArn": str,
+    },
+)
+
 ListTagsForResourceOutputTypeDef = TypedDict(
     "ListTagsForResourceOutputTypeDef",
     {
@@ -1045,6 +1293,31 @@ ListTagsForResourceOutputTypeDef = TypedDict(
     },
 )
 
+_RequiredListWorkflowTypesInputRequestTypeDef = TypedDict(
+    "_RequiredListWorkflowTypesInputRequestTypeDef",
+    {
+        "domain": str,
+        "registrationStatus": RegistrationStatusType,
+    },
+)
+_OptionalListWorkflowTypesInputRequestTypeDef = TypedDict(
+    "_OptionalListWorkflowTypesInputRequestTypeDef",
+    {
+        "name": str,
+        "nextPageToken": str,
+        "maximumPageSize": int,
+        "reverseOrder": bool,
+    },
+    total=False,
+)
+
+
+class ListWorkflowTypesInputRequestTypeDef(
+    _RequiredListWorkflowTypesInputRequestTypeDef, _OptionalListWorkflowTypesInputRequestTypeDef
+):
+    pass
+
+
 _RequiredMarkerRecordedEventAttributesTypeDef = TypedDict(
     "_RequiredMarkerRecordedEventAttributesTypeDef",
     {
@@ -1077,22 +1350,81 @@ PaginatorConfigTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredPendingTaskCountTypeDef = TypedDict(
-    "_RequiredPendingTaskCountTypeDef",
+PendingTaskCountTypeDef = TypedDict(
+    "PendingTaskCountTypeDef",
     {
         "count": int,
+        "truncated": bool,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
-_OptionalPendingTaskCountTypeDef = TypedDict(
-    "_OptionalPendingTaskCountTypeDef",
+
+_RequiredPollForActivityTaskInputRequestTypeDef = TypedDict(
+    "_RequiredPollForActivityTaskInputRequestTypeDef",
     {
-        "truncated": bool,
+        "domain": str,
+        "taskList": "TaskListTypeDef",
+    },
+)
+_OptionalPollForActivityTaskInputRequestTypeDef = TypedDict(
+    "_OptionalPollForActivityTaskInputRequestTypeDef",
+    {
+        "identity": str,
     },
     total=False,
 )
 
 
-class PendingTaskCountTypeDef(_RequiredPendingTaskCountTypeDef, _OptionalPendingTaskCountTypeDef):
+class PollForActivityTaskInputRequestTypeDef(
+    _RequiredPollForActivityTaskInputRequestTypeDef, _OptionalPollForActivityTaskInputRequestTypeDef
+):
+    pass
+
+
+_RequiredPollForDecisionTaskInputRequestTypeDef = TypedDict(
+    "_RequiredPollForDecisionTaskInputRequestTypeDef",
+    {
+        "domain": str,
+        "taskList": "TaskListTypeDef",
+    },
+)
+_OptionalPollForDecisionTaskInputRequestTypeDef = TypedDict(
+    "_OptionalPollForDecisionTaskInputRequestTypeDef",
+    {
+        "identity": str,
+        "nextPageToken": str,
+        "maximumPageSize": int,
+        "reverseOrder": bool,
+    },
+    total=False,
+)
+
+
+class PollForDecisionTaskInputRequestTypeDef(
+    _RequiredPollForDecisionTaskInputRequestTypeDef, _OptionalPollForDecisionTaskInputRequestTypeDef
+):
+    pass
+
+
+_RequiredRecordActivityTaskHeartbeatInputRequestTypeDef = TypedDict(
+    "_RequiredRecordActivityTaskHeartbeatInputRequestTypeDef",
+    {
+        "taskToken": str,
+    },
+)
+_OptionalRecordActivityTaskHeartbeatInputRequestTypeDef = TypedDict(
+    "_OptionalRecordActivityTaskHeartbeatInputRequestTypeDef",
+    {
+        "details": str,
+    },
+    total=False,
+)
+
+
+class RecordActivityTaskHeartbeatInputRequestTypeDef(
+    _RequiredRecordActivityTaskHeartbeatInputRequestTypeDef,
+    _OptionalRecordActivityTaskHeartbeatInputRequestTypeDef,
+):
     pass
 
 
@@ -1126,6 +1458,89 @@ RecordMarkerFailedEventAttributesTypeDef = TypedDict(
     },
 )
 
+_RequiredRegisterActivityTypeInputRequestTypeDef = TypedDict(
+    "_RequiredRegisterActivityTypeInputRequestTypeDef",
+    {
+        "domain": str,
+        "name": str,
+        "version": str,
+    },
+)
+_OptionalRegisterActivityTypeInputRequestTypeDef = TypedDict(
+    "_OptionalRegisterActivityTypeInputRequestTypeDef",
+    {
+        "description": str,
+        "defaultTaskStartToCloseTimeout": str,
+        "defaultTaskHeartbeatTimeout": str,
+        "defaultTaskList": "TaskListTypeDef",
+        "defaultTaskPriority": str,
+        "defaultTaskScheduleToStartTimeout": str,
+        "defaultTaskScheduleToCloseTimeout": str,
+    },
+    total=False,
+)
+
+
+class RegisterActivityTypeInputRequestTypeDef(
+    _RequiredRegisterActivityTypeInputRequestTypeDef,
+    _OptionalRegisterActivityTypeInputRequestTypeDef,
+):
+    pass
+
+
+_RequiredRegisterDomainInputRequestTypeDef = TypedDict(
+    "_RequiredRegisterDomainInputRequestTypeDef",
+    {
+        "name": str,
+        "workflowExecutionRetentionPeriodInDays": str,
+    },
+)
+_OptionalRegisterDomainInputRequestTypeDef = TypedDict(
+    "_OptionalRegisterDomainInputRequestTypeDef",
+    {
+        "description": str,
+        "tags": List["ResourceTagTypeDef"],
+    },
+    total=False,
+)
+
+
+class RegisterDomainInputRequestTypeDef(
+    _RequiredRegisterDomainInputRequestTypeDef, _OptionalRegisterDomainInputRequestTypeDef
+):
+    pass
+
+
+_RequiredRegisterWorkflowTypeInputRequestTypeDef = TypedDict(
+    "_RequiredRegisterWorkflowTypeInputRequestTypeDef",
+    {
+        "domain": str,
+        "name": str,
+        "version": str,
+    },
+)
+_OptionalRegisterWorkflowTypeInputRequestTypeDef = TypedDict(
+    "_OptionalRegisterWorkflowTypeInputRequestTypeDef",
+    {
+        "description": str,
+        "defaultTaskStartToCloseTimeout": str,
+        "defaultExecutionStartToCloseTimeout": str,
+        "defaultTaskList": "TaskListTypeDef",
+        "defaultTaskPriority": str,
+        "defaultChildPolicy": ChildPolicyType,
+        "defaultLambdaRole": str,
+    },
+    total=False,
+)
+
+
+class RegisterWorkflowTypeInputRequestTypeDef(
+    _RequiredRegisterWorkflowTypeInputRequestTypeDef,
+    _OptionalRegisterWorkflowTypeInputRequestTypeDef,
+):
+    pass
+
+
 RequestCancelActivityTaskDecisionAttributesTypeDef = TypedDict(
     "RequestCancelActivityTaskDecisionAttributesTypeDef",
     {
@@ -1215,6 +1630,29 @@ class RequestCancelExternalWorkflowExecutionInitiatedEventAttributesTypeDef(
     pass
 
 
+_RequiredRequestCancelWorkflowExecutionInputRequestTypeDef = TypedDict(
+    "_RequiredRequestCancelWorkflowExecutionInputRequestTypeDef",
+    {
+        "domain": str,
+        "workflowId": str,
+    },
+)
+_OptionalRequestCancelWorkflowExecutionInputRequestTypeDef = TypedDict(
+    "_OptionalRequestCancelWorkflowExecutionInputRequestTypeDef",
+    {
+        "runId": str,
+    },
+    total=False,
+)
+
+
+class RequestCancelWorkflowExecutionInputRequestTypeDef(
+    _RequiredRequestCancelWorkflowExecutionInputRequestTypeDef,
+    _OptionalRequestCancelWorkflowExecutionInputRequestTypeDef,
+):
+    pass
+
+
 _RequiredResourceTagTypeDef = TypedDict(
     "_RequiredResourceTagTypeDef",
     {
@@ -1234,6 +1672,96 @@ class ResourceTagTypeDef(_RequiredResourceTagTypeDef, _OptionalResourceTagTypeDe
     pass
 
 
+_RequiredRespondActivityTaskCanceledInputRequestTypeDef = TypedDict(
+    "_RequiredRespondActivityTaskCanceledInputRequestTypeDef",
+    {
+        "taskToken": str,
+    },
+)
+_OptionalRespondActivityTaskCanceledInputRequestTypeDef = TypedDict(
+    "_OptionalRespondActivityTaskCanceledInputRequestTypeDef",
+    {
+        "details": str,
+    },
+    total=False,
+)
+
+
+class RespondActivityTaskCanceledInputRequestTypeDef(
+    _RequiredRespondActivityTaskCanceledInputRequestTypeDef,
+    _OptionalRespondActivityTaskCanceledInputRequestTypeDef,
+):
+    pass
+
+
+_RequiredRespondActivityTaskCompletedInputRequestTypeDef = TypedDict(
+    "_RequiredRespondActivityTaskCompletedInputRequestTypeDef",
+    {
+        "taskToken": str,
+    },
+)
+_OptionalRespondActivityTaskCompletedInputRequestTypeDef = TypedDict(
+    "_OptionalRespondActivityTaskCompletedInputRequestTypeDef",
+    {
+        "result": str,
+    },
+    total=False,
+)
+
+
+class RespondActivityTaskCompletedInputRequestTypeDef(
+    _RequiredRespondActivityTaskCompletedInputRequestTypeDef,
+    _OptionalRespondActivityTaskCompletedInputRequestTypeDef,
+):
+    pass
+
+
+_RequiredRespondActivityTaskFailedInputRequestTypeDef = TypedDict(
+    "_RequiredRespondActivityTaskFailedInputRequestTypeDef",
+    {
+        "taskToken": str,
+    },
+)
+_OptionalRespondActivityTaskFailedInputRequestTypeDef = TypedDict(
+    "_OptionalRespondActivityTaskFailedInputRequestTypeDef",
+    {
+        "reason": str,
+        "details": str,
+    },
+    total=False,
+)
+
+
+class RespondActivityTaskFailedInputRequestTypeDef(
+    _RequiredRespondActivityTaskFailedInputRequestTypeDef,
+    _OptionalRespondActivityTaskFailedInputRequestTypeDef,
+):
+    pass
+
+
+_RequiredRespondDecisionTaskCompletedInputRequestTypeDef = TypedDict(
+    "_RequiredRespondDecisionTaskCompletedInputRequestTypeDef",
+    {
+        "taskToken": str,
+    },
+)
+_OptionalRespondDecisionTaskCompletedInputRequestTypeDef = TypedDict(
+    "_OptionalRespondDecisionTaskCompletedInputRequestTypeDef",
+    {
+        "decisions": List["DecisionTypeDef"],
+        "executionContext": str,
+    },
+    total=False,
+)
+
+
+class RespondDecisionTaskCompletedInputRequestTypeDef(
+    _RequiredRespondDecisionTaskCompletedInputRequestTypeDef,
+    _OptionalRespondDecisionTaskCompletedInputRequestTypeDef,
+):
+    pass
+
+
 ResponseMetadataTypeDef = TypedDict(
     "ResponseMetadataTypeDef",
     {
@@ -1249,8 +1777,8 @@ RunTypeDef = TypedDict(
     "RunTypeDef",
     {
         "runId": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 _RequiredScheduleActivityTaskDecisionAttributesTypeDef = TypedDict(
@@ -1405,6 +1933,31 @@ class SignalExternalWorkflowExecutionInitiatedEventAttributesTypeDef(
     pass
 
 
+_RequiredSignalWorkflowExecutionInputRequestTypeDef = TypedDict(
+    "_RequiredSignalWorkflowExecutionInputRequestTypeDef",
+    {
+        "domain": str,
+        "workflowId": str,
+        "signalName": str,
+    },
+)
+_OptionalSignalWorkflowExecutionInputRequestTypeDef = TypedDict(
+    "_OptionalSignalWorkflowExecutionInputRequestTypeDef",
+    {
+        "runId": str,
+        "input": str,
+    },
+    total=False,
+)
+
+
+class SignalWorkflowExecutionInputRequestTypeDef(
+    _RequiredSignalWorkflowExecutionInputRequestTypeDef,
+    _OptionalSignalWorkflowExecutionInputRequestTypeDef,
+):
+    pass
+
+
 _RequiredStartChildWorkflowExecutionDecisionAttributesTypeDef = TypedDict(
     "_RequiredStartChildWorkflowExecutionDecisionAttributesTypeDef",
     {
@@ -1535,6 +2088,37 @@ StartTimerFailedEventAttributesTypeDef = TypedDict(
     },
 )
 
+_RequiredStartWorkflowExecutionInputRequestTypeDef = TypedDict(
+    "_RequiredStartWorkflowExecutionInputRequestTypeDef",
+    {
+        "domain": str,
+        "workflowId": str,
+        "workflowType": "WorkflowTypeTypeDef",
+    },
+)
+_OptionalStartWorkflowExecutionInputRequestTypeDef = TypedDict(
+    "_OptionalStartWorkflowExecutionInputRequestTypeDef",
+    {
+        "taskList": "TaskListTypeDef",
+        "taskPriority": str,
+        "input": str,
+        "executionStartToCloseTimeout": str,
+        "tagList": List[str],
+        "taskStartToCloseTimeout": str,
+        "childPolicy": ChildPolicyType,
+        "lambdaRole": str,
+    },
+    total=False,
+)
+
+
+class StartWorkflowExecutionInputRequestTypeDef(
+    _RequiredStartWorkflowExecutionInputRequestTypeDef,
+    _OptionalStartWorkflowExecutionInputRequestTypeDef,
+):
+    pass
+
+
 TagFilterTypeDef = TypedDict(
     "TagFilterTypeDef",
     {
@@ -1542,6 +2126,14 @@ TagFilterTypeDef = TypedDict(
     },
 )
 
+TagResourceInputRequestTypeDef = TypedDict(
+    "TagResourceInputRequestTypeDef",
+    {
+        "resourceArn": str,
+        "tags": List["ResourceTagTypeDef"],
+    },
+)
+
 TaskListTypeDef = TypedDict(
     "TaskListTypeDef",
     {
@@ -1549,6 +2141,32 @@ TaskListTypeDef = TypedDict(
     },
 )
 
+_RequiredTerminateWorkflowExecutionInputRequestTypeDef = TypedDict(
+    "_RequiredTerminateWorkflowExecutionInputRequestTypeDef",
+    {
+        "domain": str,
+        "workflowId": str,
+    },
+)
+_OptionalTerminateWorkflowExecutionInputRequestTypeDef = TypedDict(
+    "_OptionalTerminateWorkflowExecutionInputRequestTypeDef",
+    {
+        "runId": str,
+        "reason": str,
+        "details": str,
+        "childPolicy": ChildPolicyType,
+    },
+    total=False,
+)
+
+
+class TerminateWorkflowExecutionInputRequestTypeDef(
+    _RequiredTerminateWorkflowExecutionInputRequestTypeDef,
+    _OptionalTerminateWorkflowExecutionInputRequestTypeDef,
+):
+    pass
+
+
 TimerCanceledEventAttributesTypeDef = TypedDict(
     "TimerCanceledEventAttributesTypeDef",
     {
@@ -1589,6 +2207,37 @@ class TimerStartedEventAttributesTypeDef(
     pass
 
 
+UndeprecateActivityTypeInputRequestTypeDef = TypedDict(
+    "UndeprecateActivityTypeInputRequestTypeDef",
+    {
+        "domain": str,
+        "activityType": "ActivityTypeTypeDef",
+    },
+)
+
+UndeprecateDomainInputRequestTypeDef = TypedDict(
+    "UndeprecateDomainInputRequestTypeDef",
+    {
+        "name": str,
+    },
+)
+
+UndeprecateWorkflowTypeInputRequestTypeDef = TypedDict(
+    "UndeprecateWorkflowTypeInputRequestTypeDef",
+    {
+        "domain": str,
+        "workflowType": "WorkflowTypeTypeDef",
+    },
+)
+
+UntagResourceInputRequestTypeDef = TypedDict(
+    "UntagResourceInputRequestTypeDef",
+    {
+        "resourceArn": str,
+        "tagKeys": List[str],
+    },
+)
+
 WorkflowExecutionCancelRequestedEventAttributesTypeDef = TypedDict(
     "WorkflowExecutionCancelRequestedEventAttributesTypeDef",
     {
@@ -1699,51 +2348,27 @@ class WorkflowExecutionContinuedAsNewEventAttributesTypeDef(
     pass
 
 
-_RequiredWorkflowExecutionCountTypeDef = TypedDict(
-    "_RequiredWorkflowExecutionCountTypeDef",
+WorkflowExecutionCountTypeDef = TypedDict(
+    "WorkflowExecutionCountTypeDef",
     {
         "count": int,
-    },
-)
-_OptionalWorkflowExecutionCountTypeDef = TypedDict(
-    "_OptionalWorkflowExecutionCountTypeDef",
-    {
         "truncated": bool,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-
-class WorkflowExecutionCountTypeDef(
-    _RequiredWorkflowExecutionCountTypeDef, _OptionalWorkflowExecutionCountTypeDef
-):
-    pass
-
-
-_RequiredWorkflowExecutionDetailTypeDef = TypedDict(
-    "_RequiredWorkflowExecutionDetailTypeDef",
+WorkflowExecutionDetailTypeDef = TypedDict(
+    "WorkflowExecutionDetailTypeDef",
     {
         "executionInfo": "WorkflowExecutionInfoTypeDef",
         "executionConfiguration": "WorkflowExecutionConfigurationTypeDef",
         "openCounts": "WorkflowExecutionOpenCountsTypeDef",
-    },
-)
-_OptionalWorkflowExecutionDetailTypeDef = TypedDict(
-    "_OptionalWorkflowExecutionDetailTypeDef",
-    {
         "latestActivityTaskTimestamp": datetime,
         "latestExecutionContext": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-
-class WorkflowExecutionDetailTypeDef(
-    _RequiredWorkflowExecutionDetailTypeDef, _OptionalWorkflowExecutionDetailTypeDef
-):
-    pass
-
-
 _RequiredWorkflowExecutionFailedEventAttributesTypeDef = TypedDict(
     "_RequiredWorkflowExecutionFailedEventAttributesTypeDef",
     {
@@ -1802,27 +2427,15 @@ class WorkflowExecutionInfoTypeDef(
     pass
 
 
-_RequiredWorkflowExecutionInfosTypeDef = TypedDict(
-    "_RequiredWorkflowExecutionInfosTypeDef",
+WorkflowExecutionInfosTypeDef = TypedDict(
+    "WorkflowExecutionInfosTypeDef",
     {
         "executionInfos": List["WorkflowExecutionInfoTypeDef"],
-    },
-)
-_OptionalWorkflowExecutionInfosTypeDef = TypedDict(
-    "_OptionalWorkflowExecutionInfosTypeDef",
-    {
         "nextPageToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-
-class WorkflowExecutionInfosTypeDef(
-    _RequiredWorkflowExecutionInfosTypeDef, _OptionalWorkflowExecutionInfosTypeDef
-):
-    pass
-
-
 _RequiredWorkflowExecutionOpenCountsTypeDef = TypedDict(
     "_RequiredWorkflowExecutionOpenCountsTypeDef",
     {
@@ -1961,6 +2574,7 @@ WorkflowTypeDetailTypeDef = TypedDict(
     {
         "typeInfo": "WorkflowTypeInfoTypeDef",
         "configuration": "WorkflowTypeConfigurationTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
@@ -2007,27 +2621,15 @@ class WorkflowTypeInfoTypeDef(_RequiredWorkflowTypeInfoTypeDef, _OptionalWorkflo
     pass
 
 
-_RequiredWorkflowTypeInfosTypeDef = TypedDict(
-    "_RequiredWorkflowTypeInfosTypeDef",
+WorkflowTypeInfosTypeDef = TypedDict(
+    "WorkflowTypeInfosTypeDef",
     {
         "typeInfos": List["WorkflowTypeInfoTypeDef"],
-    },
-)
-_OptionalWorkflowTypeInfosTypeDef = TypedDict(
-    "_OptionalWorkflowTypeInfosTypeDef",
-    {
         "nextPageToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-
-class WorkflowTypeInfosTypeDef(
-    _RequiredWorkflowTypeInfosTypeDef, _OptionalWorkflowTypeInfosTypeDef
-):
-    pass
-
-
 WorkflowTypeTypeDef = TypedDict(
     "WorkflowTypeTypeDef",
     {
